//----------------------------------------------------------------------------
//
// License:  LGPL
// 
// See LICENSE.txt file in the top level directory for more details.
//
// Author:  David Burken
//
// Description: ossimWkt class declaration. A well known text utility class.
// 
//----------------------------------------------------------------------------
// $Id$

#ifndef ossimWkt_HEADER
#define ossimWkt_HEADER 1

#include <ossim/base/ossimConstants.h>
#include <ossim/base/ossimRefPtr.h>
#include <ossim/projection/ossimProjection.h>

#include <iosfwd>
#include <string>
#include <vector>

// Forward class declarations:

/** @class Public container class. */
class OSSIM_DLL ossimWktGroup
{
public:
   ossimWktGroup();
   ~ossimWktGroup();

   std::string m_name;
   std::vector<std::string> m_strings;
   std::vector<ossimWktGroup> m_groups;
};

/**
 * @class ossimWkt
 *
 * Utility/support data class to extract the projection from a dot aux dot xml
 * file commonly found with mrsid data.
 */
class OSSIM_DLL ossimWkt
{
public:
   
   /** default constructor */
   ossimWkt();

   /** destructor */
   ~ossimWkt();

   bool open( const std::string& wkt );
   
   /**
    * @brief Method to get a projection if possible.
    * @param file File name to open.
    * @return Projection pointer wrapped in ref pointer.  Can be null if
    * projection cannot be established.
    */
   ossimRefPtr<ossimProjection> getProjection() const;

private:

   bool parseWktGroup( std::istringstream& is, ossimWktGroup& wktGroup );
   
   std::string   m_wkt;
   ossimWktGroup m_wktGroup;
};

#endif /* End of "#ifndef ossimWkt_HEADER" */
