//----------------------------------------------------------------------------
//
// License:  LGPL
// 
// See LICENSE.txt file in the top level directory for more details.
//
// Description:
//
// Test app for GEOS stuff.
// 
//----------------------------------------------------------------------------
// $Id: ossim-image-geometry-test.cpp 22201 2013-03-20 00:53:33Z dburken $

#include <ossim/init/ossimInit.h>
#include <ossim/base/ossimCommon.h>

#include <ossim/projection/ossimMapProjection.h>
#include <ossim/projection/ossimProjection.h>
#include <ossim/projection/ossimProjectionFactoryRegistry.h>

#include <geos/io/WKTReader.h>

#include <iostream>
#include <iomanip>
#include <string>
#include <sstream>
#include <ctime>
using namespace std;

static void usage()
{
   cout << "ossimGeometryTest <imagefile>"
        << "\nTest image geometry." << endl;
}

int main(int argc, char *argv[])
{
   ossimInit::instance()->initialize(argc, argv);

   if (argc != 1)
   {
      usage();
      return 0;
   }

   geos::io::WKTReader wktReader;
   geos::geom::Geometry* geom = 0;


   std::string wkt = "COMPD_CS[\"unknown\",PROJCS[\"NAD83 / UTM zone 11N\",GEOGCS[\"NAD83\",DATUM[\"North_American_Datum_1983\",SPHEROID[\"GRS 1980\",6378137,298.2572221010002,AUTHORITY[\"EPSG\",\"7019\"]],AUTHORITY[\"EPSG\",\"6269\"]],PRIMEM[\"Greenwich\",0],UNIT[\"degree\",0.0174532925199433],AUTHORITY[\"EPSG\",\"4269\"]],PROJECTION[\"Transverse_Mercator\"],PARAMETER[\"latitude_of_origin\",0],PARAMETER[\"central_meridian\",-117],PARAMETER[\"scale_factor\",0.9996],PARAMETER[\"false_easting\",500000],PARAMETER[\"false_northing\",0],UNIT[\"metre\",1,AUTHORITY[\"EPSG\",\"9001\"]],AUTHORITY[\"EPSG\",\"26911\"]],VERT_CS[\"NAVD88 - Geoid09 (Meters)\",VERT_DATUM[\"unknown\",2005],UNIT[\"metre\",1.0,AUTHORITY[\"EPSG\",\"9001\"]],AXIS[\"Up\",UP]]]";
      
   cout << "Testing return from wkt string: " << wkt << endl;
   try
   {
      geom = wktReader.read( wkt );
      if ( geom )
      {
         cout << "got geom..." << endl;
      }
      else
      {
         cout << "Null geom!" << endl;
      }
      
      if ( geom )
      {
         delete geom;
         geom = 0;
      }
   }
   catch( const std::exception& e )
   {
      cerr << "Caught exception: " << e.what() << endl;
   }
   
   wkt = "PROJCS[\"NAD83 / UTM zone 11N\",GEOGCS[\"NAD83\",DATUM[\"North_American_Datum_1983\",SPHEROID[\"GRS 1980\",6378137,298.2572221010002,AUTHORITY[\"EPSG\",\"7019\"]],AUTHORITY[\"EPSG\",\"6269\"]],PRIMEM[\"Greenwich\",0],UNIT[\"degree\",0.0174532925199433],AUTHORITY[\"EPSG\",\"4269\"]],PROJECTION[\"Transverse_Mercator\"],PARAMETER[\"latitude_of_origin\",0],PARAMETER[\"central_meridian\",-117],PARAMETER[\"scale_factor\",0.9996],PARAMETER[\"false_easting\",500000],PARAMETER[\"false_northing\",0],UNIT[\"metre\",1,AUTHORITY[\"EPSG\",\"9001\"]],AUTHORITY[\"EPSG\",\"26911\"]]";

      
   cout << "Testing return from wkt string: " << wkt << endl;
   try
   {
      geom = wktReader.read( wkt );
      if ( geom )
      {
         cout << "got geom..." << endl;
      }
      else
      {
         cout << "Null geom!" << endl;
      }
      
      if ( geom )
      {
         delete geom;
         geom = 0;
      }
   }
   catch( const std::exception& e )
   {
      cerr << "Caught exception: " << e.what() << endl;
   }

   

   
   return 0;
}

